#!/bin/bash
# vim: tabstop=4:softtabstop=4:shiftwidth=4:noexpandtab

basedir=~/.socr/work
logsdir=~/.socr/logs

if [ -e '/usr/sbin/screencapture' ]; then
  SCREENCAPTURE='/usr/sbin/screencapture'
elif [ ! -z "$(which screencapture)" ]; then
  SCREENCAPTURE="$(which screencapture)"
else
  printf "FATAL ERROR: Could not find screencapture.\n" 2>&1
fi

if [ -e '/opt/local/bin/mogrify' ]; then
  MOGRIFY='/opt/local/bin/mogrify'
elif [ ! -z "$(which mogrify)" ]; then
  MOGRIFY="$(which mogrify)"
else
  printf "FATAL ERROR: Could not find mogrify.\nMake sure MacPorts (http://macports.org) is installed, then do 'sudo port install ImageMagick'.\n" 2>&1
fi

if [ -e '/opt/local/bin/tesseract' ]; then
  TESSERACT='/opt/local/bin/tesseract'
elif [ ! -z "$(which tesseract)" ]; then
  TESSERACT="$(which tesseract)"
else
  printf "FATAL ERROR: Could not find tesseract.\nMake sure MacPorts (http://macports.org) is installed, then do 'sudo port install tesseract'.\nYou will also need to install the language file you would like tesseract to understand, eg. 'port install tesseract-eng'.\n" 2>&1
fi


frame="${KMPARAM_X},${KMPARAM_Y},${KMPARAM_Width},${KMPARAM_Height}"
name="socr_$(date '+%Y-%m-%d_%H.%M.%S')_at_${frame}"
logfile="${logsdir}/socr_log_$(date '+%Y-%m-%d').txt"

mkdir -p "${basedir}"
mkdir -p "${logsdir}"
basename="${basedir}/${name}"

echo >> "${logfile}"
echo ============================================================================ >> "${logfile}"
echo "frame: ${frame}" >> "${logfile}"
echo "name: ${name}" >> "${logfile}"

${SCREENCAPTURE} -x -o -tpng -R${frame} -T0 "${basename}.png" >> "${logfile}" 2>&1

# There are seemingly endless ways to tweak the image in pre-processing.  We
# do very minimal tweak here.
#
# Sometimes it's better strip all color (-modulate 100,0)
#   http://www.imagemagick.org/script/command-line-options.php#modulate
#${MOGRIFY} -modulate 100,0 -resize 500% "${basename}.png" >> "${logfile}" 2>&1
#
# Increasing size by 500% helps with screenshots where fonts are typically very small
# compared to what you'd expect from a scanned image.
${MOGRIFY} -resize 500% "${basename}.png" >> "${logfile}" 2>&1

# Process PNG and get basename.TXT file
${TESSERACT} "${basename}.png" "${basename}" 2>> "${logfile}"


cat "${basename}.txt" 2>> "${logfile}" | perl -wn <(cat <<'EOPERL'
	chomp;
	s/^\s+//g;
	s/\s+$//g;
	next if /^$/;
	print $_;
EOPERL
) | tee -a "${logfile}"

find ~/.socr -type f -exec rm {} \; &> /dev/null &

exit 0


# EOF
